==> modonomicon-1.21.8-fabric-1.116.0-sources.jar: com/klikli_dev/modonomicon/util/StreamCodecs.java <==
// SPDX-FileCopyrightText: 2024 klikli-dev
//
// SPDX-License-Identifier: MIT

package com.klikli_dev.modonomicon.util;

import com.mojang.datafixers.util.Function7;
import java.util.function.Function;
import net.minecraft.class_9139;

public class StreamCodecs {
    public static <B, C, T1, T2, T3, T4, T5, T6, T7> class_9139<B, C> composite(
            final class_9139<? super B, T1> pCodec1,
            final Function<C, T1> pGetter1,
            final class_9139<? super B, T2> pCodec2,
            final Function<C, T2> pGetter2,
            final class_9139<? super B, T3> pCodec3,
            final Function<C, T3> pGetter3,
            final class_9139<? super B, T4> pCodec4,
            final Function<C, T4> pGetter4,
            final class_9139<? super B, T5> pCodec5,
            final Function<C, T5> pGetter5,
            final class_9139<? super B, T6> pCodec6,
            final Function<C, T6> pGetter6,
            final class_9139<? super B, T7> pCodec7,
            final Function<C, T7> pGetter7,
            final Function7<T1, T2, T3, T4, T5, T6, T7, C> pFactory
    ) {
        return new class_9139<B, C>() {
            @Override
            public C decode(B p_330310_) {
                T1 t1 = pCodec1.decode(p_330310_);
                T2 t2 = pCodec2.decode(p_330310_);
                T3 t3 = pCodec3.decode(p_330310_);
                T4 t4 = pCodec4.decode(p_330310_);
                T5 t5 = pCodec5.decode(p_330310_);
                T6 t6 = pCodec6.decode(p_330310_);
                T7 t7 = pCodec7.decode(p_330310_);
                return pFactory.apply(t1, t2, t3, t4, t5, t6, t7);
            }

            @Override
            public void encode(B p_332052_, C p_331912_) {
                pCodec1.encode(p_332052_, pGetter1.apply(p_331912_));
                pCodec2.encode(p_332052_, pGetter2.apply(p_331912_));
                pCodec3.encode(p_332052_, pGetter3.apply(p_331912_));
                pCodec4.encode(p_332052_, pGetter4.apply(p_331912_));
                pCodec5.encode(p_332052_, pGetter5.apply(p_331912_));
                pCodec6.encode(p_332052_, pGetter6.apply(p_331912_));
                pCodec7.encode(p_332052_, pGetter7.apply(p_331912_));
            }
        };
    }
}

==> modonomicon-1.21.10-fabric-1.119.0-sources.jar: com/klikli_dev/modonomicon/util/StreamCodecs.java <==
// SPDX-FileCopyrightText: 2024 klikli-dev
//
// SPDX-License-Identifier: MIT

package com.klikli_dev.modonomicon.util;

import com.mojang.datafixers.util.Function7;
import org.jetbrains.annotations.NotNull;

import java.util.function.Function;
import net.minecraft.class_2540;
import net.minecraft.class_9139;

public class StreamCodecs {
    public static <B extends class_2540, V extends Enum<V>> class_9139<B, V> enumCodec(Class<V> enumClass) {
        return new class_9139<>() {
            @Override
            public @NotNull V decode(@NotNull B buf) {
                return buf.method_10818(enumClass);
            }

            @Override
            public void encode(@NotNull B buf, @NotNull V value) {
                buf.method_10817(value);
            }
        };
    }

    public static <B, C, T1, T2, T3, T4, T5, T6, T7> class_9139<B, C> composite(
            final class_9139<? super B, T1> pCodec1,
            final Function<C, T1> pGetter1,
            final class_9139<? super B, T2> pCodec2,
            final Function<C, T2> pGetter2,
            final class_9139<? super B, T3> pCodec3,
            final Function<C, T3> pGetter3,
            final class_9139<? super B, T4> pCodec4,
            final Function<C, T4> pGetter4,
            final class_9139<? super B, T5> pCodec5,
            final Function<C, T5> pGetter5,
            final class_9139<? super B, T6> pCodec6,
            final Function<C, T6> pGetter6,
            final class_9139<? super B, T7> pCodec7,
            final Function<C, T7> pGetter7,
            final Function7<T1, T2, T3, T4, T5, T6, T7, C> pFactory
    ) {
        return new class_9139<B, C>() {
            @Override
            public C decode(B p_330310_) {
                T1 t1 = pCodec1.decode(p_330310_);
                T2 t2 = pCodec2.decode(p_330310_);
                T3 t3 = pCodec3.decode(p_330310_);
                T4 t4 = pCodec4.decode(p_330310_);
                T5 t5 = pCodec5.decode(p_330310_);
                T6 t6 = pCodec6.decode(p_330310_);
                T7 t7 = pCodec7.decode(p_330310_);
                return pFactory.apply(t1, t2, t3, t4, t5, t6, t7);
            }

            @Override
            public void encode(B p_332052_, C p_331912_) {
                pCodec1.encode(p_332052_, pGetter1.apply(p_331912_));
                pCodec2.encode(p_332052_, pGetter2.apply(p_331912_));
                pCodec3.encode(p_332052_, pGetter3.apply(p_331912_));
                pCodec4.encode(p_332052_, pGetter4.apply(p_331912_));
                pCodec5.encode(p_332052_, pGetter5.apply(p_331912_));
                pCodec6.encode(p_332052_, pGetter6.apply(p_331912_));
                pCodec7.encode(p_332052_, pGetter7.apply(p_331912_));
            }
        };
    }
}
